﻿#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2013 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using System.ComponentModel;
using HeuristicLab.Common;

namespace HeuristicLab.Problems.Instances.QAPGenerator {
  public abstract class QAPInstanceGeneratorDescriptor : IDataDescriptor, IContent, INotifyPropertyChanged {

    public virtual string Name {
      get { return "Parameterizable QAP Instance"; }
    }

    public virtual string Description {
      get { return "Specifies the parameters for a randomly generator QAP instance."; }
    }

    private int n;
    public int N {
      get { return n; }
      set {
        if (n == value) return;
        n = value;
        OnPropertyChanged("N");
      }
    }

    private int seed;
    public int Seed {
      get { return seed; }
      set {
        if (seed == value) return;
        seed = value;
        OnPropertyChanged("Seed");
      }
    }

    public virtual bool IsConfigurationValid { get { return n > 2; } }

    public abstract QAPData GetInstance();

    public event PropertyChangedEventHandler PropertyChanged;
    protected void OnPropertyChanged(string propertyName) {
      var handler = PropertyChanged;
      if (handler != null) handler(this, new PropertyChangedEventArgs(propertyName));
    }
  }
}
